package com.care.client.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.care.bms.service.BmsEventOrderService;
import com.care.client.service.PassportService;
import com.care.client.service.PinanbaoService;
import com.care.client.vo.DeviceMonitorVO;
import com.care.client.vo.MemberInfoVO;
import com.care.common.annotation.Permission;
import com.care.common.enums.OrderStatusEnum;
import com.care.common.exception.BDException;
import com.care.common.util.PageResult;
import com.care.common.util.Result;
import com.care.common.util.WebPageUtils;
import com.care.common.vo.PageReqVO;
import com.care.common.vo.UserLogindConvertVO;
import com.care.common.vo.device.DeviceVO;
import com.care.common.vo.event.*;
import com.care.common.vo.outcall.CcCallResultVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * @Author: lilt
 * @Date: 2021/5/26
 * @Desc:
 */
@RestController
@Api(value = "EventHandleController", tags = { "房屋信息" })
@Slf4j
@RequestMapping("/pinanbao/house")
@Permission
public class HouseApiController {
    @Resource
    private PassportService passportService;
    @Autowired
    private PinanbaoService pinanbaoService;
    //TODO 设备列表
    //todo 某个设备的心率、呼吸
    //TODO 某个设备的睡眠报告 夜间、白天

    /**
     *设备列表
     * @param token
     * @return
     */
    @GetMapping("/device/list")
    @ApiOperation(tags = {"首页"},value = "设备列表")
    public Result<List<DeviceVO>> listNotHandle(@RequestHeader(value = "token") String token){
        try {
            MemberInfoVO current = passportService.checkToken(token);
            List<DeviceVO> datas = pinanbaoService.devList(current.getId());
            return Result.success(datas);
        }catch (BDException e) {
            log.error("未处理事件查询-分页列表出现异常",e);
            return  PageResult.error(e.getMessage());
        } catch (Exception e) {
            log.error("事件处理: 未处理事件查询出现异常",e);
            return PageResult.error( "获取列表失败");
        }
    }

    @GetMapping("/device/monitor")
    @ApiOperation(tags = {"首页"},value = "设备的监测信息")
    public Result<DeviceMonitorVO> listNotHandle(@RequestHeader(value = "token") String token, @RequestParam("devId") Long devId){
        try {

            return Result.success(this.pinanbaoService.devMonitorData(devId));
        }catch (BDException e) {
            log.error("未处理事件查询-分页列表出现异常",e);
            return  PageResult.error(e.getMessage());
        } catch (Exception e) {
            log.error("事件处理: 未处理事件查询出现异常",e);
            return PageResult.error( "获取列表失败");
        }
    }

}
